//--------LICENSE_START--------
//
// Copyright (C) 2020,2021,2022,2023,2024 Institut de Robòtica i Informàtica Industrial, CSIC-UPC.
// Authors: Joan Solà Ortega (jsola@iri.upc.edu)
// All rights reserved.
//
// This file is part of WOLF
// WOLF is free software: you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
//--------LICENSE_END--------
#ifndef FEATURE_GNSS_FIX_H_
#define FEATURE_GNSS_FIX_H_

//Wolf includes
#include "core/feature/feature_base.h"

//std includes
#include "gnss_utils/gnss_utils.h"
#include "gnss_utils/utils/rcv_position.h"

namespace wolf {

WOLF_PTR_TYPEDEFS(FeatureGnssFix);

//class FeatureGnssFix
class FeatureGnssFix : public FeatureBase
{
    public:

        /** \brief Constructor from capture pointer and measure
         *
         * \param _measurement the measurement
         * \param _meas_covariance the noise of the measurement
         *
         */
        FeatureGnssFix(const GnssUtils::ComputePosOutput& _gnss_fix_output);

        ~FeatureGnssFix() override{};

    private:
        GnssUtils::ComputePosOutput gnss_fix_output_;

};

inline FeatureGnssFix::FeatureGnssFix(const GnssUtils::ComputePosOutput& _gnss_fix_output) :
        FeatureBase("FeatureGnssFix", 
                    (Eigen::Vector4d() << _gnss_fix_output.pos, _gnss_fix_output.rcv_bias(0)).finished(), 
                    _gnss_fix_output.sol_cov),
        gnss_fix_output_(_gnss_fix_output)
{
    //
};

} // namespace wolf

#endif
