//--------LICENSE_START--------
//
// Copyright (C) 2020,2021,2022,2023,2024 Institut de Robòtica i Informàtica Industrial, CSIC-UPC.
// Authors: Joan Solà Ortega (jsola@iri.upc.edu)
// All rights reserved.
//
// This file is part of WOLF
// WOLF is free software: you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
//--------LICENSE_END--------
#ifndef FEATURE_GNSS_SATELLITE_H_
#define FEATURE_GNSS_SATELLITE_H_

//Wolf includes
#include "core/feature/feature_base.h"

//std includes
#include "gnss_utils/range.h"
#include "gnss_utils/utils/satellite.h"

namespace wolf {

WOLF_PTR_TYPEDEFS(FeatureGnssSatellite);
WOLF_LIST_TYPEDEFS(FeatureGnssSatellite);

//class FeatureGnssSatellite
class FeatureGnssSatellite : public FeatureBase
{
    public:

        /** \brief Constructor
         *
         * \param _obs_sat satellite observation in rtklib format
         *
         * This constructor will take the pseudorange as measurement with 1 m² of variance
         *
         */
        FeatureGnssSatellite(const obsd_t& _obs_sat, const GnssUtils::Satellite& _sat, const GnssUtils::Range& _range);

        ~FeatureGnssSatellite() override{};

        const obsd_t& getObservation() const;
        int satNumber() const;
        const GnssUtils::Satellite& getSatellite() const;
        const GnssUtils::Range& getRange() const;

    private:
      obsd_t obs_sat_;
      GnssUtils::Satellite sat_;
      GnssUtils::Range range_;
};


} // namespace wolf

// IMPLEMENTATION
namespace wolf {

inline FeatureGnssSatellite::FeatureGnssSatellite(const obsd_t& _obs_sat, const GnssUtils::Satellite& _sat, const GnssUtils::Range& _range) :
    FeatureBase("FeatureGnssPseudoRange", Eigen::Vector1d(_range.P_corrected), Eigen::Matrix1d(_range.P_var)),
    obs_sat_(_obs_sat),
    sat_(_sat),
    range_(_range)
{
    //
}

inline const obsd_t& FeatureGnssSatellite::getObservation() const
{
    return obs_sat_;
}

inline int FeatureGnssSatellite::satNumber() const
{
    return obs_sat_.sat;
}

inline const GnssUtils::Satellite& FeatureGnssSatellite::getSatellite() const
{
    return sat_;
}

inline const GnssUtils::Range& FeatureGnssSatellite::getRange() const
{
    return range_;
}

} // namespace wolf

#endif
